// Af.java
// Envia uma pdu para uma maquina pedindo um oid
// Eh o agente tradutor SNMP
// Autor: Marcelo Goncalves Rubinstein
// Baseado em: snmpget.java da AdventNet
// Data: 30/03/00
// Ultima modificacao: 31/03/00
// Uso: mole.apps.Af ()
// Parametros defaults: community = public, porta = 161, retries = 0 e
// timeout = 5000ms


import java.lang.*;
import java.util.*;
import java.net.*;
import com.adventnet.snmp.snmp2.*;

//---------------------------------------------------------------------------

public class Agente_Tradutor extends AgFixo {


//---------------------------------------------------------------------------

public Agente_Tradutor() 
{
}

//---------------------------------------------------------------------------

public static String consulta(String host, String variavel) 
{

	// Start SNMP API
	SnmpAPI api;
    api = new SnmpAPI();
    api.start();
    
    // Open session
    SnmpSession session = new SnmpSession(api);        

    // set remote Host 
    session.setPeername (host);
	session.setRemotePort (6000);

    // Build Get request PDU
    SnmpPDU pdu = new SnmpPDU();
    pdu.setCommand( api.GET_REQ_MSG );

    // add OID
        SnmpOID oid = new SnmpOID(variavel);
        if (oid.toValue() == null) 
            System.out.println("Invalid OID argument: ");
        else pdu.addNull(oid);

    try {
        //Open session
        session.open();
    } catch (SnmpException e) {
        System.out.println("Error opening session:"+e.getMessage());
    }


    try {
        // Send PDU and receive response PDU
        pdu = session.syncSend(pdu);
    } catch (SnmpException e) {
        System.out.println("Sending PDU"+e.getMessage());
    }    
    if (pdu == null) {
        // timeout
        System.out.println("Request timed out" );
    }

    // Check for error in response
    if (pdu.getErrstat() != 0)
        System.out.println(pdu.getError());
    else 
        // print the response pdu varbinds

    // close session
    session.close();
    // stop api thread
    api.close();

	return new String (pdu.printVarBinds());
}


//---------------------------------------------------------------------------


public static String atualiza(String host, String variavel, 
								String oid_type, String oid_value) {

	// Start SNMP API
	SnmpAPI api;
    api = new SnmpAPI();
    api.start();
    
    // Open session
    SnmpSession session = new SnmpSession(api);        

    // set remote Host 
    session.setPeername (host);

    // set remote port
	session.setRemotePort (6000);
	
	// Build Set request PDU
    SnmpPDU pdu = new SnmpPDU();
    pdu.setCommand( api.SET_REQ_MSG );

    // add Variable Bindings
        SnmpOID oid = new SnmpOID(variavel);
        if (oid.toValue() == null) 
            System.out.println("Invalid OID argument: ");
        else addvarbind(pdu, oid, oid_type, oid_value);

	//end of add variable bindings

	try {
        //Open session
        session.open();
    } catch (SnmpException e) {
        System.out.println("Error opening session:"+e.getMessage());
    }


    try {
        // Send PDU and receive response PDU
        pdu = session.syncSend(pdu);
    } catch (SnmpException e) {
        System.out.println("Sending PDU"+e.getMessage());
    }    
    if (pdu == null) {
        // timeout
        System.out.println("Request timed out" );
    }

    // Check for error in response
    if (pdu.getErrstat() != 0)
        System.out.println(pdu.getError());

    // close session
    session.close();
    // stop api thread
    api.close();

	return new String (pdu.printVarBinds());

}

//---------------------------------------------------------------------------

/** adds the varbind  with specified oid, type and value to the pdu */
 static void addvarbind(SnmpPDU pdu, SnmpOID oid, String type, String value)
     {        
         byte dataType ;
         if (type.equals("INTEGER")) {
         	dataType = SnmpAPI.INTEGER;
         } else if (type.equals("STRING")) {
             dataType = SnmpAPI.STRING;
         } else if (type.equals("GAUGE")) {
             dataType = SnmpAPI.GAUGE;
         } else if (type.equals("TIMETICKS")) {
             dataType = SnmpAPI.TIMETICKS;
         } else if (type.equals("OPAQUE")) {
             dataType = SnmpAPI.OPAQUE;
         } else if (type.equals("IPADDRESS")) {
             dataType = SnmpAPI.IPADDRESS;
         } else if (type.equals("COUNTER")) {
             dataType = SnmpAPI.COUNTER;
         } else if (type.equals("OID")) { 
             dataType = SnmpAPI.OBJID;
         } else { 
	         System.err.println("Invalid variable type: " + type);
	         return;
	     }

		 SnmpVar var = null;
		 try {   
			// create SnmpVar instance for the value and the type
		    var = SnmpVar.createVariable( value, dataType );
	     }
		 catch(SnmpException e){
        	 System.err.println("Cannot create variable: " + oid + " with value: " + value);
		     return;
         }
        //create varbind
        SnmpVarBind varbind = new SnmpVarBind(oid, var);
        // add variable binding
        pdu.addVariableBinding(varbind);
}

//---------------------------------------------------------------------------

}
